@@ -1,4 +1,4 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
 #
 # Copyright 2002 Ben Escoto <ben@emerose.org>
 # Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
@@ -19,33 +19,44 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-import sys
+from __future__ import print_function
+from __future__ import division
+from future import standard_library
+standard_library.install_aliases()
+from builtins import range
+from builtins import object
+from past.utils import old_div
+
 import os
-import unittest
+import platform
+import pytest
 import random
+import unittest
 
 from duplicity import gpg
 from duplicity import path
+from testing import _runtest_dir
 from . import UnitTestCase
 
 
+@pytest.mark.usefixtures(u"redirect_stdin")
 class GPGTest(UnitTestCase):
-    """Test GPGFile"""
+    u"""Test GPGFile"""
     def setUp(self):
         super(GPGTest, self).setUp()
         self.unpack_testfiles()
-        self.default_profile = gpg.GPGProfile(passphrase="foobar")
+        self.default_profile = gpg.GPGProfile(passphrase=u"foobar")
 
     def gpg_cycle(self, s, profile=None):
-        """Test encryption/decryption cycle on string s"""
-        epath = path.Path("testfiles/output/encrypted_file")
+        u"""Test encryption/decryption cycle on string s"""
+        epath = path.Path(u"{0}/testfiles/output/encrypted_file".format(_runtest_dir))
         if not profile:
             profile = self.default_profile
         encrypted_file = gpg.GPGFile(1, epath, profile)
         encrypted_file.write(s)
         encrypted_file.close()
 
-        epath2 = path.Path("testfiles/output/encrypted_file")
+        epath2 = path.Path(u"{0}/testfiles/output/encrypted_file".format(_runtest_dir))
         decrypted_file = gpg.GPGFile(0, epath2, profile)
         dec_buf = decrypted_file.read()
         decrypted_file.close()
@@ -53,53 +64,53 @@ class GPGTest(UnitTestCase):
         assert s == dec_buf, (len(s), len(dec_buf))
 
     def test_gpg1(self):
-        """Test gpg short strings"""
-        self.gpg_cycle("hello, world")
-        self.gpg_cycle("ansoetuh aoetnuh aoenstuh aoetnuh asoetuh saoteuh ")
+        u"""Test gpg short strings"""
+        self.gpg_cycle(b"hello, world")
+        self.gpg_cycle(b"ansoetuh aoetnuh aoenstuh aoetnuh asoetuh saoteuh ")
 
     def test_gpg2(self):
-        """Test gpg long strings easily compressed"""
-        self.gpg_cycle(" " * 50000)
-        self.gpg_cycle("aoeu" * 1000000)
+        u"""Test gpg long strings easily compressed"""
+        self.gpg_cycle(b" " * 50000)
+        self.gpg_cycle(b"aoeu" * 1000000)
 
     def test_gpg3(self):
-        """Test on random data - must have /dev/urandom device"""
-        infp = open("/dev/urandom", "rb")
+        u"""Test on random data - must have /dev/urandom device"""
+        infp = open(u"/dev/urandom", u"rb")
         rand_buf = infp.read(120000)
         infp.close()
         self.gpg_cycle(rand_buf)
 
     def test_gpg_asym(self):
-        """Test GPG asymmetric encryption"""
+        u"""Test GPG asymmetric encryption"""
         profile = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                  recipients=[self.encrypt_key1,
                                              self.encrypt_key2])
-        self.gpg_cycle("aoensutha aonetuh saoe", profile)
+        self.gpg_cycle(b"aoensutha aonetuh saoe", profile)
 
         profile2 = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                   recipients=[self.encrypt_key1])
-        self.gpg_cycle("aoeu" * 10000, profile2)
+        self.gpg_cycle(b"aoeu" * 10000, profile2)
 
     def test_gpg_hidden_asym(self):
-        """Test GPG asymmetric encryption with hidden key id"""
+        u"""Test GPG asymmetric encryption with hidden key id"""
         profile = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                  hidden_recipients=[self.encrypt_key1,
                                                     self.encrypt_key2])
-        self.gpg_cycle("aoensutha aonetuh saoe", profile)
+        self.gpg_cycle(b"aoensutha aonetuh saoe", profile)
 
         profile2 = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                   hidden_recipients=[self.encrypt_key1])
-        self.gpg_cycle("aoeu" * 10000, profile2)
+        self.gpg_cycle(b"aoeu" * 10000, profile2)
 
     def test_gpg_signing(self):
-        """Test to make sure GPG reports the proper signature key"""
-        plaintext = "hello" * 50000
+        u"""Test to make sure GPG reports the proper signature key"""
+        plaintext = b"hello" * 50000
 
         signing_profile = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                          sign_key=self.sign_key,
                                          recipients=[self.encrypt_key1])
 
-        epath = path.Path("testfiles/output/encrypted_file")
+        epath = path.Path(u"{0}/testfiles/output/encrypted_file".format(_runtest_dir))
         encrypted_signed_file = gpg.GPGFile(1, epath, signing_profile)
         encrypted_signed_file.write(plaintext)
         encrypted_signed_file.close()
@@ -108,17 +119,17 @@ class GPGTest(UnitTestCase):
         assert decrypted_file.read() == plaintext
         decrypted_file.close()
         sig = decrypted_file.get_signature()
-        assert sig == self.sign_key, sig[-8:]
+        assert sig == self.sign_key, sig
 
     def test_gpg_signing_and_hidden_encryption(self):
-        """Test to make sure GPG reports the proper signature key even with hidden encryption key id"""
-        plaintext = "hello" * 50000
+        u"""Test to make sure GPG reports the proper signature key even with hidden encryption key id"""
+        plaintext = b"hello" * 50000
 
         signing_profile = gpg.GPGProfile(passphrase=self.sign_passphrase,
                                          sign_key=self.sign_key,
                                          hidden_recipients=[self.encrypt_key1])
 
-        epath = path.Path("testfiles/output/encrypted_file")
+        epath = path.Path(u"{0}/testfiles/output/encrypted_file".format(_runtest_dir))
         encrypted_signed_file = gpg.GPGFile(1, epath, signing_profile)
         encrypted_signed_file.write(plaintext)
         encrypted_signed_file.close()
@@ -127,59 +138,60 @@ class GPGTest(UnitTestCase):
         assert decrypted_file.read() == plaintext
         decrypted_file.close()
         sig = decrypted_file.get_signature()
-        assert sig == self.sign_key, sig[-8:]
+        assert sig == self.sign_key, sig
 
+    @unittest.skipIf(platform.machine() in [u"ppc64el", u"ppc64le"], u"Skip on ppc64el of ppc64el machines")
     def test_GPGWriteFile(self):
-        """Test GPGWriteFile"""
+        u"""Test GPGWriteFile"""
         size = 400 * 1000
         gwfh = GPGWriteFile_Helper()
-        profile = gpg.GPGProfile(passphrase="foobar")
-        for i in range(10):  # @UnusedVariable
-            gpg.GPGWriteFile(gwfh, "testfiles/output/gpgwrite.gpg",
+        profile = gpg.GPGProfile(passphrase=u"foobar")
+        for i in range(10):
+            gpg.GPGWriteFile(gwfh, u"{0}/testfiles/output/gpgwrite.gpg".format(_runtest_dir),
                              profile, size=size)
-            # print os.stat("testfiles/output/gpgwrite.gpg").st_size-size
-            assert size - 64 * 1024 <= os.stat("testfiles/output/gpgwrite.gpg").st_size <= size + 64 * 1024
+            # print os.stat("/tmp/testfiles/output/gpgwrite.gpg").st_size-size
+            assert size - 64 * 1024 <= os.stat(u"{0}/testfiles/output/gpgwrite.gpg".format(_runtest_dir)).st_size <= size + 64 * 1024
         gwfh.set_at_end()
-        gpg.GPGWriteFile(gwfh, "testfiles/output/gpgwrite.gpg",
+        gpg.GPGWriteFile(gwfh, u"{0}/testfiles/output/gpgwrite.gpg".format(_runtest_dir),
                          profile, size=size)
-        # print os.stat("testfiles/output/gpgwrite.gpg").st_size
+        # print os.stat("/tmp/testfiles/output/gpgwrite.gpg").st_size
 
     def test_GzipWriteFile(self):
-        """Test GzipWriteFile"""
+        u"""Test GzipWriteFile"""
         size = 400 * 1000
         gwfh = GPGWriteFile_Helper()
-        for i in range(10):  # @UnusedVariable
-            gpg.GzipWriteFile(gwfh, "testfiles/output/gzwrite.gz",
+        for i in range(10):
+            gpg.GzipWriteFile(gwfh, u"{0}/testfiles/output/gzwrite.gz".format(_runtest_dir),
                               size=size)
-            # print os.stat("testfiles/output/gzwrite.gz").st_size-size
-            assert size - 64 * 1024 <= os.stat("testfiles/output/gzwrite.gz").st_size <= size + 64 * 1024
+            # print os.stat("/tmp/testfiles/output/gzwrite.gz").st_size-size
+            assert size - 64 * 1024 <= os.stat(u"{0}/testfiles/output/gzwrite.gz".format(_runtest_dir)).st_size <= size + 64 * 1024
         gwfh.set_at_end()
-        gpg.GzipWriteFile(gwfh, "testfiles/output/gzwrite.gz", size=size)
-        # print os.stat("testfiles/output/gzwrite.gz").st_size
+        gpg.GzipWriteFile(gwfh, u"{0}/testfiles/output/gzwrite.gz".format(_runtest_dir), size=size)
+        # print os.stat("/tmp/testfiles/output/gzwrite.gz").st_size
 
 
-class GPGWriteHelper2:
+class GPGWriteHelper2(object):
     def __init__(self, data):
         self.data = data
 
 
-class GPGWriteFile_Helper:
-    """Used in test_GPGWriteFile above"""
+class GPGWriteFile_Helper(object):
+    u"""Used in test_GPGWriteFile above"""
     def __init__(self):
-        self.from_random_fp = open("/dev/urandom", "rb")
+        self.from_random_fp = open(u"/dev/urandom", u"rb")
         self.at_end = 0
 
     def set_at_end(self):
-        """Iterator stops when you call this"""
+        u"""Iterator stops when you call this"""
         self.at_end = 1
 
     def get_buffer(self, size):
-        """Return buffer of size size, consisting of half random data"""
-        s1 = size / 2
+        u"""Return buffer of size size, consisting of half random data"""
+        s1 = int(old_div(size, 2))
         s2 = size - s1
-        return "a" * s1 + self.from_random_fp.read(s2)
+        return b"a" * s1 + self.from_random_fp.read(s2)
 
-    def next(self):
+    def __next__(self):
         if self.at_end:
             raise StopIteration
         block_data = self.get_buffer(self.get_read_size())
@@ -193,19 +205,19 @@ class GPGWriteFile_Helper:
             return random.randrange(0, size)
 
     def get_footer(self):
-        return "e" * random.randrange(0, 15000)
+        return b"e" * random.randrange(0, 15000)
 
 
 class SHATest(UnitTestCase):
-    """Test making sha signatures"""
+    u"""Test making sha signatures"""
     def setUp(self):
         super(SHATest, self).setUp()
         self.unpack_testfiles()
 
     def test_sha(self):
-        hash = gpg.get_hash("SHA1", path.Path("testfiles/various_file_types/regular_file"))
-        assert hash == "886d722999862724e1e62d0ac51c468ee336ef8e", hash
+        testhash = gpg.get_hash(u"SHA1", path.Path(u"{0}/testfiles/various_file_types/regular_file".format(_runtest_dir)))
+        assert testhash == u"886d722999862724e1e62d0ac51c468ee336ef8e", testhash
 
 
-if __name__ == "__main__":
+if __name__ == u"__main__":
     unittest.main()
